@@ -302,6 +302,12 @@ class DataField(BasePlural):
         "Returns a distinct set of choices for this field."
         return zip(self.values, self.labels)
 
+    @property
+    def coded_choices(self):
+        "Returns a distinct set of coded choices for this field."
+        if self.lexicon:
+            return zip(self.codes, self.labels)
+
     # Data Aggregation Properties
     def groupby(self, *args):
         return Aggregator(self.field).groupby(*args)
@@ -477,6 +483,13 @@ class DataContext(AbstractDataContext, Base):
     user = models.ForeignKey(User, null=True, blank=True, related_name='datacontext+')
     session_key = models.CharField(max_length=40, null=True, blank=True)
 
+    def __unicode__(self):
+        if self.user_id:
+            out = unicode(self.user)
+        else:
+            out = self.session_key
+        return u'{0} ({1})'.format(out, 'session' if self.session else 'archived')
+
     def archive(self):
         if self.archived:
             return False
@@ -500,6 +513,13 @@ class DataView(AbstractDataView, Base):
     user = models.ForeignKey(User, null=True, blank=True, related_name='dataview+')
     session_key = models.CharField(max_length=40, null=True, blank=True)
 
+    def __unicode__(self):
+        if self.user_id:
+            out = unicode(self.user)
+        else:
+            out = self.session_key
+        return u'{0} ({1})'.format(out, 'session' if self.session else 'archived')
+
     def archive(self):
         if self.archived:
             return False
